@@ -281,7 +281,7 @@ class predictor(object):
         
         return(valFunc)
         
-    def integratedAutoCorrelationTime(self, inputData, nMax):
+    def autoCorrelationLength(self, inputData, nMax):
         predictions = self.predict(inputData, n=1)
         output = np.squeeze(np.array(predictions)).T
         
